@@ -39,7 +39,7 @@ import Prelude hiding (catch)
 import System.IO
 import System.Exit
 import System.Log.Logger
-import System.IO.Error hiding (catch)
+import System.IO.Error (isUserError, ioeGetErrorString)
 import Data.Maybe.Utils
 import Data.Maybe
 import Data.List.Utils(uniq)
@@ -297,6 +297,9 @@ genericCommand c environ (ChanHandle ih) =
 -- Or use GHC version as a proxy:  __GLASGOW_HASKELL__ >= 720
 			    -- Added field in process 1.1.0.0:
 			    , create_group = False
+#endif
+#if MIN_VERSION_process(1,2,0)
+			    , delegate_ctlc = False
 #endif
 			   }
     in do (_, oh', _, ph) <- createProcess cp
@@ -313,6 +316,9 @@ genericCommand cspec environ ichan =
 #if MIN_VERSION_process(1,1,0)
 			    -- Added field in process 1.1.0.0:
 			    , create_group = False
+#endif
+#if MIN_VERSION_process(1,2,0)
+			    , delegate_ctlc = False
 #endif
 			   }
     in do (ih', oh', _, ph) <- createProcess cp
@@ -494,7 +500,7 @@ checkResults (cmd, ps) =
 {- | Handle an exception derived from a program exiting abnormally -}
 tryEC :: IO a -> IO (Either ExitCode a)
 tryEC action =
-    do r <- try action
+    do r <-  Control.Exception.try action
        case r of
          Left ioe ->
           if isUserError ioe then
